@@ -26,8 +26,8 @@ static QString identifierToPath(const QString &identifier)
     return dataDir + QString::fromLatin1(QUrl::toPercentEncoding(identifier));
 }
 
-CachedProvider::CachedProvider(QObject *parent, const KPluginMetaData &data, IdentifierType type, const QString &identifier)
-    : ComicProvider(parent, data, type, identifier)
+CachedProvider::CachedProvider(QObject *parent, const KPluginMetaData &data, RequestReason reason, IdentifierType type, const QString &identifier)
+    : ComicProvider(parent, data, reason, type, identifier)
 {
     QTimer::singleShot(0, this, &CachedProvider::triggerFinished);
 }
@@ -137,7 +137,7 @@ bool CachedProvider::storeInCache(const QString &identifier, const QImage &comic
         // We need to delete the most recent cached strip if there's a newer one,
         // as its nextIdentifier needs to be updated. We can't set it directly,
         // as there may have been multiple strips released since the last check.
-        QString encodedFullIdentifier = QString::fromLatin1(QUrl::toPercentEncoding(comicName + ":" + oldCachedStripIdentifier));
+        QString encodedFullIdentifier = QString::fromLatin1(QUrl::toPercentEncoding(comicName + QLatin1String(":") + oldCachedStripIdentifier));
         QFile::remove(dirPath + encodedFullIdentifier);
         QFile::remove(dirPath + encodedFullIdentifier + QLatin1String(".conf"));
         comics.removeAll(encodedFullIdentifier);
